# PermitASD

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**special_desig_location_text** | **str** | Max length 255 characters Use Street Lookup API endpoint /nsg/streets to lookup this information | [optional] 
**special_desig_description** | **str** | Max length 300 characters Use Street Lookup API endpoint /nsg/streets to lookup this information | [optional] 
**special_desig_start_date** | **datetime** | Use Street Lookup API endpoint /nsg/streets to lookup this information | [optional] 
**special_desig_start_time** | **float** | Is whole number between 0 and 2400 inclusive Use Street Lookup API endpoint /nsg/streets to lookup this information | [optional] 
**special_desig_end_date** | **datetime** | Use Street Lookup API endpoint /nsg/streets to lookup this information | [optional] 
**special_desig_end_time** | **float** | Is whole number between 0 and 2400 inclusive Use Street Lookup API endpoint /nsg/streets to lookup this information | [optional] 
**street_special_desig_code** | [**ASDCode**](ASDCode.md) |  | 
**special_desig_periodicity_code** | **AllOfPermitASDSpecialDesigPeriodicityCode** | Use Street Lookup API endpoint /nsg/streets to lookup this information | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

